from setuptools import setup

setup(name='udemyproj',
      version='1.0',
      description='Calculate and visuallize, Gaussian, Binomial and Normal distributions',
      packages=['udemyproj'],
      author_email='sjahnaviprasad@gmail.com',
      zip_safe=False)
